<?php
/**
 *	Line In Pages Base Class
 *
 *	@version 0.2.2
 *	@author	Simon Fairbairn 
 */
 


if ( !class_exists('LIBC_Pages') ) {
	
	abstract class LIBC_Pages  {
		protected	$options = array();
		protected 	$options_page = null;

	
		function __construct() {
			if ( $this->show_settings_link ) {
				if ( $this->plugin_basename ) {
					add_filter("plugin_action_links_" . $this->plugin_basename, array( &$this, 'add_settings_link' ) );
				} else {
					wp_die( "Plugin basename not set" );
				}
			} 
			
			if ( is_admin() ) {
				if ( $this->menu_page !== null ) {
					add_action('admin_menu', array( &$this, 'add_menu_page' ) );
				
				}
				if ( $this->submenu_pages !== null ) {
				
					add_action('admin_menu', array( &$this, 'add_submenu_pages' ) );
				
				}
				
			}

		}
		
		/**
		 *	Check to see if the options exisit in the database. If not, get the defaults
		 *	and load them in.
		 */
		public function add_settings_link($links) { 
			$settings_link = '<a href="options-general.php?page=' . $this->plugin_id . '">Settings</a>'; 
			array_unshift($links, $settings_link); 
			return $links; 
		}
		
		
		/* Menu Pages */
		public function add_menu_page() {
			if ( isset ( $this->menu_page['title'] ) ) {
				$title = $this->menu_page['title'];
			} else {
				$title = $this->plugin_title;
			}
			
		
			$options_page = add_menu_page( $title, $title, 'manage_options', $this->plugin_id, array( &$this, 'parent_page'), $this->menu_page['icon_url'], $this->menu_page['position']);		
			$this->parent_page = $this->plugin_id;
			
			
			add_action('admin_print_styles-' . $options_page, array( &$this, 'enqueue_styles') );
			add_action('admin_print_styles-widgets.php', array( &$this, 'enqueue_styles') );
			add_action('admin_print_styles-' . $options_page, array( &$this, 'enqueue_scripts') );		
						
			add_action( 'load-' . $options_page, array(&$this, 'load_meta_boxes') );
			if ( isset( $this->menu_page['help_callback'] ) ) {
				$method = $this->menu_page['help_callback'];
				add_contextual_help( $options_page, $this->$method()  );			
			}

			
		}
		
		
		
		
		public function add_submenu_pages() {

			$pages = 0;
			foreach( $this->submenu_pages as $page ) {
				$this->options_page[$pages] = add_submenu_page(
					$this->parent_page, 
					$page['title'], 
					$page['title'], 
					'manage_options', 
					$page['id'], 
					array( &$this, $page['page_callback']) 
				);
				add_action('admin_print_styles-' . $this->options_page[$pages], array( &$this, 'enqueue_styles') );
				add_action('admin_print_styles-widgets.php', array( &$this, 'enqueue_styles') );
				add_action('admin_print_styles-' . $this->options_page[$pages], array( &$this, 'enqueue_scripts') );		
				add_action( 'load-' . $this->options_page[$pages], array(&$this, 'load_meta_boxes') );

				if ( false !== $page['help_callback']  ) {
					$method = $page['help_callback'];
					add_contextual_help( $this->options_page[$pages], $this->$method()  );			
				}
				
				$pages++;
			}
		}
		
		/* Meta boxes */
		
		
		public function load_meta_boxes() {
			
			
			if ( $this->meta_boxes !== null ) {
				wp_enqueue_script('common');
				wp_enqueue_script('wp-lists');
				wp_enqueue_script('postbox');
				foreach ( $this->meta_boxes as $meta_box ) {
					add_meta_box( $meta_box['id'], $meta_box['title'], array( &$this, $meta_box['callback'] ), $meta_box['page'], $meta_box['position'], 'core' );
				}
			}
		}
		
		protected function _all_meta() {
			echo "<style>.postbox .inside h3 {background: none; border: 0; box-shadow: none; -moz-box-shadow: none; -webkit-box-shadow: none; -o-box-shadow: none; -ms-box-shadow: none; }</style>";
		}
		
		
		public function about_meta_html() {
			
			// This is where the default text for the About meta will go
			echo "<p>This plugin was created by <a href='http://line-in.co.uk'>Line In Web Design</a>.</p>";
		}
		
		
		/* Scripts and styles */
			
		
		public function load_scripts( $file_name, $deps = false, $ver ) {
			wp_register_script( $this->plugin_id . '-scripts', $this->scripts_url  . $file_name . '.js', $deps, $ver, true );
		}
		public function load_styles( $file_name, $deps = false, $ver ) {
			wp_register_style( $this->plugin_id . '-styles', $this->styles_url  . $file_name . '.css', $deps, $ver, 'all');
		}
		
		public function enqueue_scripts() {
			wp_enqueue_script( $this->plugin_id . '-scripts' );
		}
		
		public function enqueue_styles() {
			wp_enqueue_style( $this->plugin_id . '-styles' );
		}
		

		/* HTML Output */
		
		public function parent_page() {
			$this->page_html( $this->parent_page );
		}
		
		public function page_html( $page = false, $title = false, $callback = false ) {
			if ( false === $page ) {
				$page = $this->options_page[0];
			}
			?>
			<div class='wrap'>
				<?php screen_icon(); ?>
				<?php if ( $title ) { ?>
					<h2><?php _e( $title,  $this->lang ); ?></h2>				
				<?php } else { ?>
					<h2><?php _e( $this->plugin_title,  $this->lang ); ?></h2>
				<?php } ?>
				<?php 
				
				if ( true == $this->add_sideboxes ) {
					add_meta_box( $this->plugin_id . '-about', 'About This Plugin', array(&$this, 'about_meta_html'), $page, 'side', 'core');
					
				}
				
				/*
					
					if ( isset( $_GET['settings-updated'] ) ) {
					    echo "<div class='updated'><p>Settings updated successfully.</p></div>";
					}
					*/
				 ?>
				 <form action="options.php" method="post">
					 <?php wp_nonce_field('closedpostboxes', 'closedpostboxesnonce', false ); ?>
					 <?php wp_nonce_field('meta-box-order', 'meta-box-order-nonce', false ); ?>
					
						<div id="poststuff" class="metabox-holder<?php echo ' has-right-sidebar'; ?>">
							<div id="side-info-column" class="inner-sidebar">
								<?php  do_meta_boxes($page, 'side', null); ?>
							</div>
							<div id="post-body" class="has-sidebar">
								<div id="post-body-content" class="has-sidebar-content">
									<?php do_meta_boxes($page, 'normal', null); ?>
								</div>
							</div>
					 <p class='submit clear'><?php submit_button('Update options', 'primary','submit', false); ?> <?php submit_button('Reset options', 'secondary', 'reset', false); ?></p>

				 </form>
			</div>
			<script type="text/javascript">
				//<![CDATA[
				jQuery(document).ready( function($) {
					// close postboxes that should be closed
					$('.if-js-closed').removeClass('if-js-closed').addClass('closed');
					// postboxes setup
					postboxes.add_postbox_toggles('<?php echo $this->options_page; ?>');
				});
				//]]>
			</script>
			
			
			 <?php
		}

	}
}


?>