<?php
/*
Plugin Name: Line In Typography
Plugin URI: http://line-in.co.uk/
Description: Overlays a typographical grid and columns for theme development
Author: Simon Fairbairn
Version: 0.3.0
Requires at least: 3.0
Author URI: http://line-in.co.uk/
License: GPL
*/

/**
 *	Imports the required base classes full of plugin goodies
 */
include "classes/libc-pages.php"; 
include "classes/libc-settings-api.php"; 

global $plugin_setup_array;
/* Example setup array */
$plugin_setup_array = array(
	'plugin_id'			=>	'line-in-typography',
	'plugin_title'		=>	'Line In Typography',
	'plugin_shortname'	=>	'LI Typography',
	'plugin_abbr'		=>	'LIT',
	'parent_page'		=>	'options-general.php',

	'add_sideboxes'		=> 	true,
	'scripts'			=>	true,
	'styles'			=>	true
);

define( $plugin_setup_array['plugin_abbr'] . '_Version', '0.1.1');
define( $plugin_setup_array['plugin_abbr'] . '_Language', 'litypography');
/**
 *	
 */

register_activation_hook(__FILE__, array( 'My_Test_Plugin', 'install_plugin' ) );
register_deactivation_hook(__FILE__, array( 'My_Test_Plugin', 'uninstall_plugin') );

/**
 * Calls the class on the post edit screen
 */
function call_Line_In_Typography() 
{
	global $plugin_setup_array;
    return new Line_In_Typography($plugin_setup_array);
}
add_action( 'init', 'call_Line_In_Typography' );


if ( !class_exists( 'Line_In_Typography' ) ) {
	class Line_In_Typography extends LIBC_Pages {
		/**
		 * A way to keep track of whether this plugin is being used and only loading scripts on 
		 * those pages
		 * @access 	static
		 * @var 	boolean
		 */		
		static 		$add_script;
		/**
		 * The URL of the plugin
		 * @access 	protected
		 * @uses	plugins_url()
		 * @var 	string
		 */		
			
		protected 	$plugin_url;
		/**
		 * The plugin basename
		 * @access 	protected
		 * @uses	plugin_basename()
		 * @var 	string
		 */		
		protected 	$plugin_basename;
		/**
		 * The url of the scripts for this plugin
		 * @access 	protected
		 * @uses	Line_In_Typography::$plugin_url
		 * @var 	string
		 */		
		protected	$scripts_url;
				
		/**
		 * The url of the stylesheet for this plugin
		 * @access 	protected
		 * @uses	Line_In_Typography::$plugin_url
		 * @var 	string
		 */		
		protected	$styles_url;
		
		/**
		 * An arbitrary id identifier for this plugin.
		 * @access	protected
		 * @var		string
		 */ 
		protected 	$plugin_id;
		/**
		 * The name of the options key to be stored in the wp_options table.
		 * @access 	protected
		 * @uses	Line_In_Typography::$plugin_id
		 * @var 	string
		 */		
		protected	$options_name;
		/**
		 * The parent page that a submenu page is attached to. Needs to be set if using 
		 * @access 	protected
		 * @var 	string
		 */		
		protected 	$parent_page = null;
		/**
		 * The title for the plugin, to be used as a heading on the Options Page. 
		 * @access 	protected
		 * @usedby	LIPBC_Settings_API_With_Page::add_submenu_page()
		 * @var 	string
		 */		
		protected 	$plugin_title;
		/**
		 * An abbreviation of the title to be used on the menu itself
		 * @access 	protected
		 * @var 	string
		 */		
		protected 	$plugin_shortname;
		/**
		 * Can be populated with an array of meta boxes, or left null if you don't want to add any
		 * @access 	protected
		 * @var 	array
		 */		
		protected 	$meta_boxes = null;
		/**
		 * Whether or not to show the settings link on the Plugins page.
		 * @access 	protected
		 * @var 	boolean
		 */		
		protected	$show_settings_link = true;
		/**
		 * Can be populated with an array menu page options 
		 * @access 	protected
		 * @var 	array
		 */		
		protected 	$menu_page = null;
		/**
		 * Can be populated with an array of multiple submenu page options 
		 * @access 	protected
		 * @var 	array
		 */		
		protected 	$submenu_pages = null;
		/**
		 * Whether or not to add the sideboxes (about, etc.)
		 * @access 	protected
		 * @var 	array
		 */		
		protected 	$add_sideboxes = true;
								
		
				
		public function __construct( $options ) {
			$this->plugin_id 		= $options['plugin_id'];
			$this->plugin_title 	= $options['plugin_title'];
			$this->plugin_shortname = $options['plugin_shortname'];
			$this->plugin_abbr		= $options['plugin_abbr'];
			$this->lang				= LIT_Language;
			$this->parent_page		= $options['parent_page'];
			$this->add_sideboxes	= $options['add_sideboxes'];
		
			$this->plugin_basename = plugin_basename( __FILE__ );
			$this->plugin_url = plugins_url( '', __FILE__ ).'/';
			$this->options_name = $this->plugin_id . '_options';
			$this->scripts_url = $this->plugin_url . 'js/';
			$this->styles_url = $this->plugin_url . 'css/';			
			
			// Add submenu page
			$this->submenu_pages[] = array(
				'id'		=> $this->plugin_id,
				'title' 	=> 'Line In Typography',
				'page_callback'	=> 'first_page',
				'help_callback'	=> '_help'
				
			);
			
			// Initialise Settings API and get Settings class
			$this->settings['page_1'] = new Settings_Page_1();	
			
			$this->load_scripts('line-in-typography', array('jquery'), LIT_Version );
			
			if ( !is_admin() ) {
				add_action('wp_head', array( &$this, 'head' ) );
				add_action('wp_footer', array( &$this, 'foot' ) );
			
			} else {
				// Add settings to a meta box
				add_action( 'admin_menu', array( &$this, 'configure_meta_boxes' ), 12 );
			}
			
			parent::__construct();
				
		}
		
		
		// EXAMPLE METHODS
		public function configure_meta_boxes() {

			$this->meta_boxes = array(
				'box-1' => array( 
					'id' 		=> 	'line-in-typography',
					'title'		=> 	'Line In Typography Settings',
					'callback'	=>	'load_meta',
					'position'	=>	'normal',
					'page'		=> 	$this->options_page[0]
				)
											
			);
			
		}
		
		public function _help() {
			return "Contextual help coming soon";
		}	
		
		
		
		public function load_meta() {

			$this->_all_meta();
			$this->settings['page_1']->get_settings();
		}
	
			
		public function first_page() {
			
			$this->page_html( $this->options_page[0], 'Line In Typography' );
			
		}
		// END EXAMPLE METHODS
		
		
		static function install_plugin() {
			// Code for installation
		}
		
		static function uninstall_plugin() {
			// Code for deactivation
		}
		
		
		function head() { 
			self::$add_script = true; 
			
			?>
			<style>
				.gr960-12 {
					background: url(<?php echo $this->plugin_url; ?>css/img/960-12px.png) 0 -4px !important;
					background-size: 100% !important;
				}
				.gr960-16 {
					background: url(<?php echo $this->plugin_url; ?>css/img/960-16px.png) 0 -4px !important;
					background-size: 100% !important;
				}
				
				#lit-vertical-rhythm {
					width: 100%;
					z-index: 100;
					position: absolute;
					top: 0;
					left: 0;	
				}
				#lit-buttons {
					position: fixed;
					top: 50px;
					right: 0;
					z-index: 200;
					background: #fff;
					padding: 15px;
					border: 1px solid #000;
					-moz-border-radius: 10px;
					-webkit-border-radius: 10px;
					border-radius: 10px;
					width: 400px;
					
				}
				
				.switchImages embed, .switchImages img, .switchImages object, .switchImages video, .switchImages iframe  {
					display: none !important;	
				}
				
								
				/* =ENDDEL */
				            
            
            </style>
		<?php }
		
		
		function foot() { 
			if ( ! self::$add_script )
				return;
			wp_print_scripts($this->plugin_id . '-scripts'); 
			
			$options = $this->settings['page_1']->get_options();

			
		?>

			<script>
				/*
				 *	Variables:
				 *
				 *	containers are what the plugin is attached to
				 *
				 *	fontSizeContainer (default: body), for most of my sites it'll be wrap now
				 *	
				 *	Lines offset (default: 0), just in case you need to offset the lines
				 *
				 */
				jQuery(document).ready(function($) {
					var myOptions = {	
						pluginUrl			: "<?php echo $this->plugin_url; ?>",
						lineHeightContainer	: 'body',
						gridState			: 'on',
						lineState			: 'off',
						testHtml			: "<p><?php echo $options['paragraph-text']; ?></p>",
						showTestHtml		: '<?php echo $options['show-paragraph']; ?>',
						backgroundOffset	: <?php echo $options['background-offset']; ?>,
						lineHeight			: <?php echo $options['line-height']; ?>
					};
					$('<?php echo $options['elements']; ?>' ).LineInTypography(myOptions);
				});
			</script>

		<?php
		}
	}
	
}

// EXAMPLE SETTINGS CLASSES

class Settings_Page_1 extends LI_Settings_Base {
	
	public function __construct() {
		$this->options['name'] 	= 'li_typography_options';
		$this->options['id']		= 'typography-id';
		$this->options['intro']	= 'intro';
		$this->options['validate'] = 'validate';
		$this->defaults = array(
			'line-height' 		=> 21,
			'font-size'			=> 14,
			'elements'			=> '.container',
			'paragraph-text'	=> 'Paragraph to test line height',
			'show-paragraph'	=> 'true',
			'background-offset'	=> 0,
			'plugin-version'	=> LIT_Version
		
		);
		$this->settings = new LIBC_Settings_API( $this->options, $this->defaults,  $this  );
		add_action('admin_init', array( &$this, 'setup_settings') );
		
	}
	public function setup_settings() {
		$this->settings->add_setting( 'line_height', "Set Line Height", 'line_height' );
		$this->settings->add_setting( 'elements', "DOM Elements", 'elements' );
		$this->settings->add_setting( 'test_paragraph', "Test Paragraph Text", 'test_paragraph' );
		$this->settings->add_setting( 'show_paragraph', "Show Paragraph", 'show_paragraph' );
		$this->settings->add_setting( 'background_offset', "Background Offset", 'background_offset' );
	}
	
	public function intro() {
		?>
		 <p><?php _e( 'Manage options for the Line In Typography plugin. Refer to contextual help for more information.', LIT_Language ); ?></p>
		<?php
		
	}
	
	public function field_1() {
		echo "<input type='text' name='" . $this->options['name'] . "[line-height]' id='typography_field_1' value='" . esc_attr( $this->settings->get_option('typography_field_1') ) . "' />";
	}
	
	
	
	
	public function line_height() {
		?>
		<input type='text' name='<?php echo $this->options['name']; ?>[line-height]' value='<?php echo intval($this->settings->get_option('line-height') ); ?>' id='<?php echo $this->options['name']; ?>-line-height' size='5' /> <span class='description'>Explicitly set your line height here, or set to 0 to have the plugin try and figure it out from your theme's body styles</span>
		
		<?php
	}
	function li_typography_font_size() {
		?>
		<input type='text' name='<?php echo $this->options['name']; ?>[font-size]' value='<?php echo intval($this->settings->get_option('line-height') ); ?>' id='<?php echo $this->options['name']; ?>-font-size' size='5' /> <span class='description'>Explicitly set your font size here, or set to 0 to have the plugin try and figure it out from your theme's body styles</span>
		<?php
	}
	function elements() {
		?>
		<input type='text' name='<?php echo $this->options['name']; ?>[elements]' value='<?php echo esc_attr($this->settings->get_option('elements') ); ?>' id='<?php echo $this->options['name']; ?>-elements' /> <span class='description'>Comma separated list of DOM elements to attach the grids to</span>
		<?php
	}
	function test_paragraph() {
		?>
		<input type='text' name='<?php echo $this->options['name']; ?>[paragraph-text]' value='<?php echo esc_attr($this->settings->get_option('paragraph-text')); ?>' id='<?php echo $this->options['name']; ?>-paragraph-text' size='50' /> <span class='description'>A test paragraph to show above all content. Indicates the correct positioning on the line that all paragraphs should adhere to.</span>
		<?php
	}
					
	
	function show_paragraph() {
		?>
		<input type="radio" name="<?php echo $this->options['name']; ?>[show-paragraph]" value="true"<?php checked( 'true' == $this->settings->get_option('show-paragraph') ); ?> id='<?php echo $this->options['name']; ?>-show-paragraph-true' /><label for='<?php echo $this->options['name']; ?>-show-paragraph-true'>Yes</label>
		<input type="radio" name="<?php echo $this->options['name']; ?>[show-paragraph]" value="false"<?php checked( 'false' == $this->settings->get_option('show-paragraph') ); ?> id='<?php echo $this->options['name']; ?>-show-paragraph-false' /><label for='<?php echo $this->options['name']; ?>-show-paragraph-false'>No</label>
		
		<?php
	}
	function background_offset() {
		?>
		<input type='text' name='<?php echo $this->options['name']; ?>[background-offset]' value='<?php echo intval( $this->settings->get_option('background-offset') ); ?>' id='<?php echo $this->options['name']; ?>-background-offset' size='5' /> <span class='description'>Shift the lines up or down to get your test paragraph sitting exactly on them.</span>
		
		<?php
	}

	function validate( $input ) {
		$valid_input = $this->settings->get_options();
		$default_options = $this->default_options;
		
		if ( isset( $_POST['reset'] ) ) {
			$input = $default_options;
			add_settings_error('li_typography_settings_section', 'reset-message', "Options reset to default settings", 'updated');
		} else if ( isset( $_POST['submit'] ) ) {
			$error = false;
			if ( (int) $input['line-height'] < 0 ) {
				$input['line-height'] = $valid_input['line-height'];
				$error[] = "Line height not a valid positive integer, not updated";
			}
//				if ( (int) $input['font-size'] < 0 ) {
//					$input['font-size'] = $valid_input['font-size'];
//					$error[] = "Font size not a valid positive integer, not updated";
//				}
			$input['elements'] = wp_kses($input['elements'], array());
			if ( '' == $input['elements'] ) {
				$input['elements'] = $valid_input['elements'];
				$error[] = "You have not set a valid element to attach the grids to. Setting not updated.";	
				
			}
			
			
			$input['paragraph-text'] = wp_kses($input['paragraph-text'], array());
			$input['show-paragraph'] = ( 'true' == $input['show-paragraph'] ) ? 'true' : 'false';
			if ( 'true' == $input['show-paragraph'] && '' == $input['paragraph-text'] ) {
				$input['paragraph-text'] = $default_options['paragraph-text'];
				$error[] = "If you want to show the paragraph, you'll need some paragraph text. Set to default";
			}
			
			$input['background-offset'] = (int) $input['background-offset'];
			
			
			if ( false !== $error ) {
				$i = 0;
				$output = false;
				foreach ( $error as $err ) {
					
					if ( $i > 0 ) {
						$output .= "<br />";
					}
					$output .= $err;
					$i++;
				
				}
				add_settings_error('li_typography_settings_section', 'error-message', $output, 'error');
				add_settings_error('li_typography_settings_section', 'updated-message', "All other settings updated", 'updated');
			}
		}
		return $input;
	}

	
	
	
}

// END EXAMPLE SETTINGS CLASSES


?>